@@ -14,21 +14,23 @@ makeRLearner.surv.CoxBoost = function() {
       makeLogicalLearnerParam(id = "trace", default = FALSE, tunable = FALSE)
     ),
     par.vals = list(return.score = FALSE),
-    properties = c("numerics", "factors", "ordered", "weights", "rcens"),
+    properties = c("numerics", "factors", "ordered", "weights"),
     name = "Cox Proportional Hazards Model with Componentwise Likelihood based Boosting",
     short.name = "coxboost",
-    note = "Factors automatically get converted to dummy columns, ordered factors to integer."
+    note = "Factors automatically get converted to dummy columns, ordered factors to integer.",
+    callees = "CoxBoost"
   )
 }
 
 #' @export
 trainLearner.surv.CoxBoost = function(.learner, .task, .subset, .weights = NULL, penalty = NULL, unpen.index = NULL, ...) {
-  data = getTaskData(.task, subset = .subset, target.extra = TRUE, recode.target = "rcens")
+  data = getTaskData(.task, subset = .subset, target.extra = TRUE, recode.target = "surv")
   info = getFixDataInfo(data$data, factors.to.dummies = TRUE, ordered.to.int = TRUE)
   data$data = as.matrix(fixDataForLearner(data$data, info))
 
-  if (is.null(penalty))
+  if (is.null(penalty)) {
     penalty = 9 * sum(data$target[, 2L])
+  }
 
   attachTrainingInfo(CoxBoost::CoxBoost(
     time = data$target[, 1L],
