@@ -5,7 +5,6 @@
 
 logFunDefault = function(learner, task, resampling, measures, par.set, control, opt.path, dob,
   x.string, y, remove.nas, stage, prev.stage, prefixes) {
-
   if (stage == 1L) {
     start.time = Sys.time()
     messagef("[%s] %i: %s", prefixes[stage], dob, x.string)
@@ -21,9 +20,10 @@ logFunDefault = function(learner, task, resampling, measures, par.set, control,
 
 logFunMemory = function(learner, task, resampling, measures, par.set, control, opt.path, dob,
   x.string, y, remove.nas, stage, prev.stage, prefixes) {
-
   if (stage == 1L) {
-    gc(); gc(); gc()
+    gc()
+    gc()
+    gc()
     start.time = Sys.time()
     messagef("[%s] %i: %s", prefixes[stage], dob, x.string)
     return(list(start.time = start.time))
@@ -42,11 +42,11 @@ logFunMemory = function(learner, task, resampling, measures, par.set, control, o
 
 logFunTune = function(learner, task, resampling, measures, par.set, control, opt.path, dob,
   x, y, remove.nas, stage, prev.stage) {
-
   x.string = paramValueToString(par.set, x, show.missing.values = !remove.nas)
   # shorten tuning logging a bit. we remove the sel.learner prefix from params
-  if (inherits(learner, "ModelMultiplexer"))
+  if (inherits(learner, "ModelMultiplexer")) {
     x.string = stri_replace_all(x.string, "", regex = stri_paste(x$selected.learner, "\\."))
+  }
 
   logFunDefault(learner, task, resampling, measures, par.set, control, opt.path, dob,
     x.string, y, remove.nas, stage, prev.stage, prefixes = c("Tune-x", "Tune-y")
@@ -55,11 +55,11 @@ logFunTune = function(learner, task, resampling, measures, par.set, control, opt
 
 logFunTuneMemory = function(learner, task, resampling, measures, par.set, control, opt.path, dob,
   x, y, remove.nas, stage, prev.stage) {
-
   x.string = paramValueToString(par.set, x, show.missing.values = !remove.nas)
   # shorten tuning logging a bit. we remove the sel.learner prefix from params
-  if (inherits(learner, "ModelMultiplexer"))
+  if (inherits(learner, "ModelMultiplexer")) {
     x.string = stri_replace_all(x.string, "", regex = stri_paste(x$selected.learner, "\\."))
+  }
 
   logFunMemory(learner, task, resampling, measures, par.set, control, opt.path, dob,
     x.string, y, remove.nas, stage, prev.stage, prefixes = c("Tune-x", "Tune-y")
@@ -68,7 +68,6 @@ logFunTuneMemory = function(learner, task, resampling, measures, par.set, contro
 
 logFunFeatSel = function(learner, task, resampling, measures, par.set, control, opt.path, dob,
   x, y, remove.nas, stage, prev.stage) {
-
   x.string = sprintf("%s (%i bits)", clipString(collapse(x, ""), 80L), sum(x))
 
   logFunDefault(learner, task, resampling, measures, par.set, control, opt.path, dob,
@@ -78,11 +77,9 @@ logFunFeatSel = function(learner, task, resampling, measures, par.set, control,
 
 logFunFeatSelMemory = function(learner, task, resampling, measures, par.set, control, opt.path, dob,
   x, y, remove.nas, stage, prev.stage) {
-
   x.string = sprintf("%s (%i bits)", clipString(collapse(x, ""), 80L), sum(x))
 
   logFunMemory(learner, task, resampling, measures, par.set, control, opt.path, dob,
     x.string, y, remove.nas, stage, prev.stage, prefixes = c("FeatSel-x", "FeatSel-y")
   )
 }
-
