@@ -24,14 +24,14 @@ test_that("plotLearnerPrediction", {
   lrn = makeLearner("classif.rpart")
   plotLearnerPrediction(lrn, multiclass.task)
   dir = tempdir()
-  path = paste0(dir, "/test.svg")
+  path = file.path(dir, "test.svg")
   ggsave(path)
   doc = XML::xmlParse(path)
   testDocForStrings(doc, getLearnerShortName(lrn))
 
   plotLearnerPrediction(lrn, multiclass.task, pretty.names = FALSE)
   dir = tempdir()
-  path = paste0(dir, "/test.svg")
+  path = file.path(dir, "test.svg")
   ggsave(path)
   doc = XML::xmlParse(path)
   testDocForStrings(doc, getLearnerId(lrn))
