@@ -3,8 +3,8 @@ context("classif_geoDA")
 test_that("classif_geoDA", {
   requirePackagesOrSkip("DiscriMiner", default.method = "load")
 
-  set.seed(getOption("mlr.debug.seed"))
-  m = DiscriMiner::geoDA(multiclass.train[, -multiclass.class.col], group = multiclass.train[, multiclass.class.col])
+  m = DiscriMiner::geoDA(multiclass.train[, -multiclass.class.col],
+    group = multiclass.train[, multiclass.class.col])
   p = DiscriMiner::classify(m, newdata = multiclass.test[, -multiclass.class.col])
   testSimple("classif.geoDA", multiclass.df, multiclass.target, multiclass.train.inds, p$pred_class)
 
