@@ -3,17 +3,14 @@ context("classif_nnet")
 test_that("classif_nnet", {
   requirePackagesOrSkip("nnet", default.method = "load")
 
-  set.seed(getOption("mlr.debug.seed"))
   capture.output({
     m = nnet::nnet(multiclass.formula, size = 3, data = multiclass.train)
-    set.seed(getOption("mlr.debug.seed"))
     p = as.factor(predict(m, newdata = multiclass.test, type = "class"))
-    set.seed(getOption("mlr.debug.seed"))
     p2 = predict(m, newdata = multiclass.test, type = "raw")
     set.seed(getOption("mlr.debug.seed"))
     m = nnet::nnet(binaryclass.formula, size = 3, data = binaryclass.train)
-    set.seed(getOption("mlr.debug.seed"))
-    # for the binaryclass task the mlr positive class is not the same as the ref class of nnet
+    # for the binaryclass task the mlr positive class is not the same as the ref
+    # class of nnet
     p3 = 1 - predict(m, newdata = binaryclass.test, type = "raw")[, 1]
   })
   testSimple("classif.nnet", multiclass.df, multiclass.target,
@@ -28,17 +25,17 @@ test_that("classif_nnet", {
   }
   tp = function(model, newdata) as.factor(predict(model, newdata, type = "class"))
 
-  testCV("classif.nnet", multiclass.df, multiclass.target, tune.train = tt, tune.predict = tp,
+  testCV("classif.nnet", multiclass.df, multiclass.target, tune.train = tt,
+    tune.predict = tp,
     parset = list(size = 7, maxit = 50))
 
   # ## make sure that nnet yields the same results independent of predict.type
   task = makeClassifTask(data = binaryclass.df, target = binaryclass.target)
-  lrn = makeLearner("classif.nnet", trace = FALSE, size = 1, predict.type = "prob")
-  set.seed(getOption("mlr.debug.seed"))
+  lrn = makeLearner("classif.nnet", trace = FALSE, size = 1,
+    predict.type = "prob")
   mod = train(lrn, task = task)
   pred1 = predict(mod, task = task)
   lrn = makeLearner("classif.nnet", trace = FALSE, size = 1)
-  set.seed(getOption("mlr.debug.seed"))
   mod = train(lrn, task = task)
   pred2 = predict(mod, task = task)
   expect_equal(pred1$data$response, pred2$data$response)
