@@ -12,7 +12,8 @@ test_that("learners work: cluster", {
   lapply(lrns, testBasicLearnerProperties, task = task, hyperpars = hyperpars)
 
   # clustering, prob
-  task = subsetTask(noclass.task, subset = 1:20, features = getTaskFeatureNames(noclass.task)[1:2])
+  task = subsetTask(noclass.task, subset = 1:20,
+    features = getTaskFeatureNames(noclass.task)[1:2])
   lrns = listLearnersCustom(task, properties = "prob", create = TRUE)
   lapply(lrns, testBasicLearnerProperties, task = task, hyperpars = hyperpars,
     pred.type = "prob")
@@ -20,6 +21,7 @@ test_that("learners work: cluster", {
   # cluster with weights
   lrns = listLearnersCustom("cluster", properties = "weights", create = TRUE)
   lapply(lrns, testThatLearnerRespectsWeights, hyperpars = hyperpars,
-    task = task, train.inds = 1:20, test.inds = 1:20, weights = rep(c(1, 5), length.out = 20),
+    task = task, train.inds = 1:20, test.inds = 1:20, weights = rep(c(1, 5),
+      length.out = 20),
     pred.type = "prob", get.pred.fun = getPredictionProbabilities)
 })
